.. image:: https://fronteggstuff.blob.core.windows.net/frongegg-logos/logo-transparent.png
   :alt: Frontegg

Frontegg is a web platform where SaaS companies can set up their fully managed, scalable and brand aware - SaaS features and integrate them into their SaaS portals in up to 5 lines of code.

For more information and usage you can visit the `github repo <https://github.com/frontegg/python-sdk>`_.